package VMOMI::HostPatchManagerReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
